Install
=======

You can install :mod:`latest` from

* GitHub
* PyPI (pip)

GitHub
------

Clone repository at https://github.com/bluephlavio/latest with

.. code-block:: bash

   $ git clone https://github.com/bluephlavio/latest

Then :code:`cd` to the main directory containing :code:`setup.py` and run

.. code-block:: bash

   $ python setup.py install


PyPI
----

From the command line run

.. code-block:: bash

   $ pip install latest
